@@ -255,7 +255,7 @@ class Users(_defaults_.Defaults):
 			data["account"]["name"] = name
 		if isinstance(activated, (bool, Boolean)):
 			edits += 1
-			data["permissions"]["activated"] = bool(name)
+			data["permissions"]["activated"] = bool(activated)
 		if edits > 0:
 			response = self.save_data(email=email, username=username, data=data)
 			if not response.success: return response
